import { VaultAccountResponse, CreateTransactionResponse, TransactionArguments, AssetResponse, ExchangeResponse, TransactionResponse, TransactionFilter, CancelTransactionResponse, WalletContainerResponse, WalletAssetResponse, DepositAddressResponse, GenerateAddressResponse, OperationSuccessResponse } from "./types";
export declare class FireblocksSDK {
    private authProvider;
    private apiBaseUrl;
    private apiClient;
    /**
     * Creates a new Fireblocks API Client.
     * @param privateKey A string representation of your private key.
     * @param apiKey Your api key. This is a uuid you received from Fireblocks.
     * @param apiBaseUrl The fireblocks server URL. Leave empty to use the default server.
     */
    constructor(privateKey: string, apiKey: string, apiBaseUrl?: string);
    /**
     * Gets all assets that are currently supported by Fireblocks.
     */
    getSupportedAssets(): Promise<VaultAccountResponse[]>;
    /**
     * Gets all vault accounts for your tenant.
     */
    getVaultAccounts(): Promise<VaultAccountResponse[]>;
    /**
     * Gets a single vault account.
     * @param vaultAccountId The vault account ID.
     */
    getVaultAccount(vaultAccountId: string): Promise<VaultAccountResponse>;
    /**
     * Gets a single vault account asset.
     * @param vaultAccountId The vault account ID.
     * @param assetId The ID of the asset to get.
     */
    getVaultAccountAsset(vaultAccountId: string, assetId: string): Promise<AssetResponse>;
    /**
     * Gets deposit addresses for an asset in a vault account.
     * @param vaultAccountId The vault account ID.
     * @param assetId The ID of the asset for which to get the deposit address.
     */
    getDepositAddresses(vaultAccountId: string, assetId: string): Promise<DepositAddressResponse[]>;
    /**
     * Generates a new address for an asset in a vault account.
     * @param vaultAccountId The vault account ID.
     * @param assetId The ID of the asset for which to get the deposit address.
     */
    generateNewAddress(vaultAccountId: string, assetId: string, description?: string): Promise<GenerateAddressResponse>;
    /**
     * Gets all exchange accounts for your tenant.
     */
    getExchangeAccounts(): Promise<ExchangeResponse[]>;
    /**
     * Gets a single exchange account by ID.
     * @param exchangeAccountId The exchange account ID.
     */
    getExchangeAccount(exchangeAccountId: string): Promise<ExchangeResponse>;
    /**
     * Transfer from a main exchange account to a subaccount.
     * @param exchangeAccountId The exchange ID in Fireblocks.
     * @param subaccountId The ID of the subaccount in the exchange.
     * @param assetId The asset to transfer.
     * @param amount The amount to transfer.
     */
    transferToSubaccount(exchangeAccountId: string, subaccountId: string, assetId: string, amount: number): Promise<OperationSuccessResponse>;
    /**
     * Transfer from a subaccount to a main exchange account.
     * @param exchangeAccountId The exchange ID in Fireblocks.
     * @param subaccountId The ID of the subaccount in the exchange.
     * @param assetId The asset to transfer.
     * @param amount The amount to transfer.
     */
    transferFromSubaccount(exchangeAccountId: string, subaccountId: string, assetId: string, amount: number): Promise<OperationSuccessResponse>;
    /**
     * Gets a list of transactions matching the given filter.
     * @param filter.before Only gets transactions created before a given timestamp (in seconds).
     * @param filter.after Only gets transactions created after a given timestamp (in seconds).
     * @param filter.status Only gets transactions with the spcified status.
     */
    getTransactions(filter: TransactionFilter): Promise<TransactionResponse[]>;
    /**
     * Gets all internal wallets for your tenant.
     */
    getInternalWallets(): Promise<WalletContainerResponse[]>;
    /**
     * Gets a single internal wallet.
     * @param walletId The internal wallet ID.
     */
    getInternalWallet(walletId: string): Promise<WalletContainerResponse>;
    /**
     * Gets a single internal wallet asset.
     * @param walletId The internal wallet ID.
     * @param assetId The asset ID.
     */
    getInternalWalletAsset(walletId: string, assetId: string): Promise<WalletAssetResponse>;
    /**
     * Gets all external wallets for your tenant.
     */
    getExternalWallets(): Promise<WalletContainerResponse[]>;
    /**
     * Gets a single external wallet.
     * @param walletId The external wallet ID.
     */
    getExternalWallet(walletId: string): Promise<WalletContainerResponse>;
    /**
     * Gets a single external wallet asset.
     * @param walletId The external wallet ID.
     * @param assetId The asset ID.
     */
    getExternalWalletAsset(walletId: string, assetId: string): Promise<WalletAssetResponse>;
    /**
     * Gets detailed information for a single transaction.
     * @param txId The transaction id to query.
     */
    getTransactionById(txId: string): Promise<TransactionResponse>;
    /**
     * Cancels the selected transaction.
     * @param txId The transaction id to cancel.
     */
    cancelTransactionById(txId: string): Promise<CancelTransactionResponse>;
    /**
     * Creates a new vault account.
     * @param name A name for the new vault account.
     */
    createVaultAccount(name: string): Promise<VaultAccountResponse>;
    /**
     * Updates a vault account.
     * @param name A new name for the vault account.
     */
    updateVaultAccount(vaultAccountId: string, name: string): Promise<VaultAccountResponse>;
    /**
     * Creates a new asset within an existing vault account.
     * @param vaultAccountId The vault account ID.
     * @param assetId The asset to add.
     */
    createVaultAsset(vaultAccountId: string, assetId: string): Promise<AssetResponse>;
    createExternalWallet(name: string): Promise<WalletContainerResponse>;
    /**
     * Creates a new internal wallet.
     * @param name A name for the new internal wallet.
     */
    createInternalWallet(name: string): Promise<WalletContainerResponse>;
    /**
     * Creates a new asset within an exiting external wallet.
     * @param walletId The wallet id.
     * @param assetId The asset to add.
     * @param address The wallet address.
     * @param tag (for ripple only) The ripple account tag.
     */
    createExternalWalletAsset(walletId: string, assetId: string, address: string, tag?: string): Promise<WalletAssetResponse>;
    /**
     * Creates a new asset within an exiting internal wallet.
     * @param walletId The wallet id.
     * @param assetId The asset to add.
     * @param address The wallet address.
     * @param tag (for ripple only) The ripple account tag.
     */
    createInternalWalletAsset(walletId: string, assetId: string, address: string, tag?: string): Promise<WalletAssetResponse>;
    /**
     * Creates a new transaction with the specified options.
     */
    createTransaction(options: TransactionArguments): Promise<CreateTransactionResponse>;
}
